@@ -15,11 +15,11 @@ OpenServices::SNMP::Plugin::Updates - Expose pending security updates over SNMP
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 BASE OID
 
@@ -63,6 +63,8 @@ sub init {
     }
 
     printf STDERR "Registering %s handler.\n", __PACKAGE__;
+    # Prepopulate the cache.
+    check();
     $agent->register(__PACKAGE__, $BASEOID, \&handler);
 }
 
